Create ODK Schema from XLSX template
schema_from_odk_xlsx_template.RdConverts and odk xlsx template to a condensed version of the ODK schema retrieved by RuODK. It is only necessary to use this function if you converted your xlsx file to XML before uploading to ODK.
Arguments
- file_path
String. Path to excel file.
- label_choices
Logical. Should choices be named vectors? Default is true, downstream functions may require vectors have names
- ...
Additional arguments for
dpylr::summarize. Generally used to supply paired arguments for creating lists of choices in a given language. See example.